@@ -65,69 +65,71 @@ ASDL_NAMES option_i {
   parse_ysh_string = 57,
   parse_triple_quote = 58,
   simple_word_eval = 59,
-  dashglob = 60,
+  no_dash_glob = 60,
   command_sub_errexit = 61,
   process_sub_fail = 62,
   xtrace_rich = 63,
-  xtrace_details = 64,
+  no_xtrace_osh = 64,
   sigpipe_status_ok = 65,
   env_obj = 66,
   init_ysh_globals = 67,
   for_loop_frames = 68,
   parse_at_all = 69,
-  parse_backslash = 70,
-  parse_backticks = 71,
-  parse_dollar = 72,
-  parse_ignored = 73,
-  parse_sh_arith = 74,
-  parse_dparen = 75,
-  parse_dbracket = 76,
-  parse_bare_word = 77,
-  parse_word_join = 78,
-  no_exported = 79,
-  no_init_globals = 80,
-  simple_echo = 81,
-  simple_eval_builtin = 82,
-  simple_test_builtin = 83,
-  expand_aliases = 84,
-  progcomp = 85,
-  hostcomplete = 86,
-  histappend = 87,
-  cmdhist = 88,
-  assoc_expand_once = 89,
-  autocd = 90,
-  cdable_vars = 91,
-  cdspell = 92,
-  checkhash = 93,
-  checkjobs = 94,
-  checkwinsize = 95,
-  complete_fullquote = 96,
-  direxpand = 97,
-  dirspell = 98,
-  execfail = 99,
-  extquote = 100,
-  force_fignore = 101,
-  globasciiranges = 102,
-  globstar = 103,
-  gnu_errfmt = 104,
-  histreedit = 105,
-  histverify = 106,
-  huponexit = 107,
-  interactive_comments = 108,
-  lithist = 109,
-  localvar_inherit = 110,
-  localvar_unset = 111,
-  login_shell = 112,
-  mailwarn = 113,
-  no_empty_cmd_completion = 114,
-  nocaseglob = 115,
-  progcomp_alias = 116,
-  promptvars = 117,
-  restricted_shell = 118,
-  shift_verbose = 119,
-  sourcepath = 120,
-  xpg_echo = 121,
-  ARRAY_SIZE = 122,
+  no_parse_backslash = 70,
+  no_parse_backticks = 71,
+  no_parse_bare_word = 72,
+  no_parse_dbracket = 73,
+  no_parse_dollar = 74,
+  no_parse_dparen = 75,
+  no_parse_ignored = 76,
+  no_parse_osh = 77,
+  no_parse_sh_arith = 78,
+  no_parse_word_join = 79,
+  no_exported = 80,
+  no_init_globals = 81,
+  no_osh_builtins = 82,
+  simple_echo = 83,
+  simple_eval_builtin = 84,
+  simple_test_builtin = 85,
+  expand_aliases = 86,
+  progcomp = 87,
+  hostcomplete = 88,
+  histappend = 89,
+  cmdhist = 90,
+  assoc_expand_once = 91,
+  autocd = 92,
+  cdable_vars = 93,
+  cdspell = 94,
+  checkhash = 95,
+  checkjobs = 96,
+  checkwinsize = 97,
+  complete_fullquote = 98,
+  direxpand = 99,
+  dirspell = 100,
+  execfail = 101,
+  extquote = 102,
+  force_fignore = 103,
+  globasciiranges = 104,
+  globstar = 105,
+  gnu_errfmt = 106,
+  histreedit = 107,
+  histverify = 108,
+  huponexit = 109,
+  interactive_comments = 110,
+  lithist = 111,
+  localvar_inherit = 112,
+  localvar_unset = 113,
+  login_shell = 114,
+  mailwarn = 115,
+  no_empty_cmd_completion = 116,
+  nocaseglob = 117,
+  progcomp_alias = 118,
+  promptvars = 119,
+  restricted_shell = 120,
+  shift_verbose = 121,
+  sourcepath = 122,
+  xpg_echo = 123,
+  ARRAY_SIZE = 124,
   };
 };
 
@@ -163,62 +165,63 @@ ASDL_NAMES builtin_i {
   mapfile = 26,
   readarray = 27,
   cd = 28,
-  pushd = 29,
-  popd = 30,
-  dirs = 31,
-  pwd = 32,
-  source = 33,
-  umask = 34,
-  ulimit = 35,
-  wait = 36,
-  jobs = 37,
-  fg = 38,
-  bg = 39,
-  shopt = 40,
-  complete = 41,
-  compgen = 42,
-  compopt = 43,
-  compadjust = 44,
-  compexport = 45,
-  getopts = 46,
-  builtin = 47,
-  command = 48,
-  type = 49,
-  hash = 50,
-  help = 51,
-  history = 52,
-  fc = 53,
-  alias = 54,
-  unalias = 55,
-  bind = 56,
-  append = 57,
-  write = 58,
-  json = 59,
-  json8 = 60,
-  pp = 61,
-  hay = 62,
-  haynode = 63,
-  use = 64,
-  error = 65,
-  failed = 66,
-  fork = 67,
-  forkwait = 68,
-  redir = 69,
-  fopen = 70,
-  shvar = 71,
-  ctx = 72,
-  invoke = 73,
-  runproc = 74,
-  boolstatus = 75,
-  test = 76,
-  bracket = 77,
-  push_registers = 78,
-  source_guard = 79,
-  is_main = 80,
-  cat = 81,
-  rm = 82,
-  sleep = 83,
-  ARRAY_SIZE = 84,
+  chdir = 29,
+  pushd = 30,
+  popd = 31,
+  dirs = 32,
+  pwd = 33,
+  source = 34,
+  umask = 35,
+  ulimit = 36,
+  wait = 37,
+  jobs = 38,
+  fg = 39,
+  bg = 40,
+  shopt = 41,
+  complete = 42,
+  compgen = 43,
+  compopt = 44,
+  compadjust = 45,
+  compexport = 46,
+  getopts = 47,
+  builtin = 48,
+  command = 49,
+  type = 50,
+  hash = 51,
+  help = 52,
+  history = 53,
+  fc = 54,
+  alias = 55,
+  unalias = 56,
+  bind = 57,
+  append = 58,
+  write = 59,
+  json = 60,
+  json8 = 61,
+  pp = 62,
+  hay = 63,
+  haynode = 64,
+  use = 65,
+  error = 66,
+  failed = 67,
+  fork = 68,
+  forkwait = 69,
+  redir = 70,
+  fopen = 71,
+  shvar = 72,
+  ctx = 73,
+  invoke = 74,
+  runproc = 75,
+  boolstatus = 76,
+  test = 77,
+  bracket = 78,
+  push_registers = 79,
+  source_guard = 80,
+  is_main = 81,
+  cat = 82,
+  rm = 83,
+  sleep = 84,
+  ARRAY_SIZE = 85,
   };
 };
 
